==> monocdk-1.106.1.tar.gz: package/lib/aws-amplify/lib/source-code-providers.d.ts <==
import * as codecommit from "../../aws-codecommit";
import { SecretValue } from "../../core";
import { App, ISourceCodeProvider, SourceCodeProviderConfig } from './app';
/**
 * (experimental) Properties for a GitHub source code provider.
 *
 * @experimental
 */
export interface GitHubSourceCodeProviderProps {
    /**
     * (experimental) The user or organization owning the repository.
     *
     * @experimental
     */
    readonly owner: string;
    /**
     * (experimental) The name of the repository.
     *
     * @experimental
     */
    readonly repository: string;
    /**
     * (experimental) A personal access token with the `repo` scope.
     *
     * @experimental
     */
    readonly oauthToken: SecretValue;
}
/**
 * (experimental) GitHub source code provider.
 *
 * @experimental
 */
export declare class GitHubSourceCodeProvider implements ISourceCodeProvider {
    private readonly props;
    /**
     * @experimental
     */
    constructor(props: GitHubSourceCodeProviderProps);
    /**
     * (experimental) Binds the source code provider to an app.
     *
     * @experimental
     */
    bind(_app: App): SourceCodeProviderConfig;
}
/**
 * (experimental) Properties for a GitLab source code provider.
 *
 * @experimental
 */
export interface GitLabSourceCodeProviderProps {
    /**
     * (experimental) The user or organization owning the repository.
     *
     * @experimental
     */
    readonly owner: string;
    /**
     * (experimental) The name of the repository.
     *
     * @experimental
     */
    readonly repository: string;
    /**
     * (experimental) A personal access token with the `repo` scope.
     *
     * @experimental
     */
    readonly oauthToken: SecretValue;
}
/**
 * (experimental) GitLab source code provider.
 *
 * @experimental
 */
export declare class GitLabSourceCodeProvider implements ISourceCodeProvider {
    private readonly props;
    /**
     * @experimental
     */
    constructor(props: GitLabSourceCodeProviderProps);
    /**
     * (experimental) Binds the source code provider to an app.
     *
     * @experimental
     */
    bind(_app: App): SourceCodeProviderConfig;
}
/**
 * (experimental) Properties for a CodeCommit source code provider.
 *
 * @experimental
 */
export interface CodeCommitSourceCodeProviderProps {
    /**
     * (experimental) The CodeCommit repository.
     *
     * @experimental
     */
    readonly repository: codecommit.IRepository;
}
/**
 * (experimental) CodeCommit source code provider.
 *
 * @experimental
 */
export declare class CodeCommitSourceCodeProvider implements ISourceCodeProvider {
    private readonly props;
    /**
     * @experimental
     */
    constructor(props: CodeCommitSourceCodeProviderProps);
    /**
     * (experimental) Binds the source code provider to an app.
     *
     * @experimental
     */
    bind(app: App): SourceCodeProviderConfig;
}

==> monocdk-1.185.0.tar.gz: package/lib/aws-amplify/lib/source-code-providers.d.ts <==
import * as codecommit from '../../aws-codecommit';
import { SecretValue } from '../../core';
import { App, ISourceCodeProvider, SourceCodeProviderConfig } from './app';
/**
 * Properties for a GitHub source code provider
 */
export interface GitHubSourceCodeProviderProps {
    /**
     * The user or organization owning the repository
     */
    readonly owner: string;
    /**
     * The name of the repository
     */
    readonly repository: string;
    /**
     * A personal access token with the `repo` scope
     */
    readonly oauthToken: SecretValue;
}
/**
 * GitHub source code provider
 */
export declare class GitHubSourceCodeProvider implements ISourceCodeProvider {
    private readonly props;
    constructor(props: GitHubSourceCodeProviderProps);
    bind(_app: App): SourceCodeProviderConfig;
}
/**
 * Properties for a GitLab source code provider
 */
export interface GitLabSourceCodeProviderProps {
    /**
     * The user or organization owning the repository
     */
    readonly owner: string;
    /**
     * The name of the repository
     */
    readonly repository: string;
    /**
     * A personal access token with the `repo` scope
     */
    readonly oauthToken: SecretValue;
}
/**
 * GitLab source code provider
 */
export declare class GitLabSourceCodeProvider implements ISourceCodeProvider {
    private readonly props;
    constructor(props: GitLabSourceCodeProviderProps);
    bind(_app: App): SourceCodeProviderConfig;
}
/**
 * Properties for a CodeCommit source code provider
 */
export interface CodeCommitSourceCodeProviderProps {
    /**
     * The CodeCommit repository
     */
    readonly repository: codecommit.IRepository;
}
/**
 * CodeCommit source code provider
 */
export declare class CodeCommitSourceCodeProvider implements ISourceCodeProvider {
    private readonly props;
    constructor(props: CodeCommitSourceCodeProviderProps);
    bind(app: App): SourceCodeProviderConfig;
}
